@@ -38,6 +38,8 @@
 #include <gdcmUIDGenerator.h>
 #include <gdcmVersion.h>
 
+#define PLUGIN_NAME "gdcm"
+
 #define GDCM_VERSION_IS_ABOVE(major, minor, revision)           \
   (GDCM_MAJOR_VERSION > major ||                                \
    (GDCM_MAJOR_VERSION == major &&                              \
@@ -502,7 +504,9 @@ extern "C"
       OrthancPlugins::SetGlobalContext(context);
 
 #if defined(ORTHANC_FRAMEWORK_VERSION_IS_ABOVE)
-#  if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 7, 2)
+#  if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 12, 4)
+      Orthanc::Logging::InitializePluginContext(context, PLUGIN_NAME);
+#  elif ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 7, 2)
       Orthanc::Logging::InitializePluginContext(context);
 #  else
       Orthanc::Logging::Initialize(context);
@@ -521,7 +525,7 @@ extern "C"
         return -1;
       }
 
-      OrthancPluginSetDescription(context, "Decoder/transcoder of medical images using GDCM.");
+      OrthancPlugins::SetDescription(PLUGIN_NAME, "Decoder/transcoder of medical images using GDCM.");
 
       OrthancPlugins::OrthancConfiguration global;
 
@@ -618,7 +622,7 @@ extern "C"
 
   ORTHANC_PLUGINS_API const char* OrthancPluginGetName()
   {
-    return "gdcm";
+    return PLUGIN_NAME;
   }
 
 
